# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ClusterArgs', 'Cluster']

@pulumi.input_type
class ClusterArgs:
    def __init__(__self__, *,
                 api_server_profile: pulumi.Input['ClusterApiServerProfileArgs'],
                 cluster_profile: pulumi.Input['ClusterClusterProfileArgs'],
                 ingress_profile: pulumi.Input['ClusterIngressProfileArgs'],
                 main_profile: pulumi.Input['ClusterMainProfileArgs'],
                 network_profile: pulumi.Input['ClusterNetworkProfileArgs'],
                 resource_group_name: pulumi.Input[str],
                 service_principal: pulumi.Input['ClusterServicePrincipalArgs'],
                 worker_profile: pulumi.Input['ClusterWorkerProfileArgs'],
                 location: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a Cluster resource.
        :param pulumi.Input['ClusterApiServerProfileArgs'] api_server_profile: An `api_server_profile` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input['ClusterClusterProfileArgs'] cluster_profile: A `cluster_profile` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input['ClusterIngressProfileArgs'] ingress_profile: An `ingress_profile` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input['ClusterMainProfileArgs'] main_profile: A `main_profile` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input['ClusterNetworkProfileArgs'] network_profile: A `network_profile` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: Specifies the Resource Group where the Azure Red Hat OpenShift Cluster should exist. Changing this forces a new resource to be created.
        :param pulumi.Input['ClusterServicePrincipalArgs'] service_principal: A `service_principal` block as defined below.
        :param pulumi.Input['ClusterWorkerProfileArgs'] worker_profile: A `worker_profile` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[str] location: The location where the Azure Red Hat OpenShift Cluster should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the Azure Red Hat OpenShift Cluster to create. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        """
        pulumi.set(__self__, "api_server_profile", api_server_profile)
        pulumi.set(__self__, "cluster_profile", cluster_profile)
        pulumi.set(__self__, "ingress_profile", ingress_profile)
        pulumi.set(__self__, "main_profile", main_profile)
        pulumi.set(__self__, "network_profile", network_profile)
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        pulumi.set(__self__, "service_principal", service_principal)
        pulumi.set(__self__, "worker_profile", worker_profile)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="apiServerProfile")
    def api_server_profile(self) -> pulumi.Input['ClusterApiServerProfileArgs']:
        """
        An `api_server_profile` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "api_server_profile")

    @api_server_profile.setter
    def api_server_profile(self, value: pulumi.Input['ClusterApiServerProfileArgs']):
        pulumi.set(self, "api_server_profile", value)

    @property
    @pulumi.getter(name="clusterProfile")
    def cluster_profile(self) -> pulumi.Input['ClusterClusterProfileArgs']:
        """
        A `cluster_profile` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "cluster_profile")

    @cluster_profile.setter
    def cluster_profile(self, value: pulumi.Input['ClusterClusterProfileArgs']):
        pulumi.set(self, "cluster_profile", value)

    @property
    @pulumi.getter(name="ingressProfile")
    def ingress_profile(self) -> pulumi.Input['ClusterIngressProfileArgs']:
        """
        An `ingress_profile` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "ingress_profile")

    @ingress_profile.setter
    def ingress_profile(self, value: pulumi.Input['ClusterIngressProfileArgs']):
        pulumi.set(self, "ingress_profile", value)

    @property
    @pulumi.getter(name="mainProfile")
    def main_profile(self) -> pulumi.Input['ClusterMainProfileArgs']:
        """
        A `main_profile` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "main_profile")

    @main_profile.setter
    def main_profile(self, value: pulumi.Input['ClusterMainProfileArgs']):
        pulumi.set(self, "main_profile", value)

    @property
    @pulumi.getter(name="networkProfile")
    def network_profile(self) -> pulumi.Input['ClusterNetworkProfileArgs']:
        """
        A `network_profile` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "network_profile")

    @network_profile.setter
    def network_profile(self, value: pulumi.Input['ClusterNetworkProfileArgs']):
        pulumi.set(self, "network_profile", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[str]:
        """
        Specifies the Resource Group where the Azure Red Hat OpenShift Cluster should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="servicePrincipal")
    def service_principal(self) -> pulumi.Input['ClusterServicePrincipalArgs']:
        """
        A `service_principal` block as defined below.
        """
        return pulumi.get(self, "service_principal")

    @service_principal.setter
    def service_principal(self, value: pulumi.Input['ClusterServicePrincipalArgs']):
        pulumi.set(self, "service_principal", value)

    @property
    @pulumi.getter(name="workerProfile")
    def worker_profile(self) -> pulumi.Input['ClusterWorkerProfileArgs']:
        """
        A `worker_profile` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "worker_profile")

    @worker_profile.setter
    def worker_profile(self, value: pulumi.Input['ClusterWorkerProfileArgs']):
        pulumi.set(self, "worker_profile", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        The location where the Azure Red Hat OpenShift Cluster should be created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Azure Red Hat OpenShift Cluster to create. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _ClusterState:
    def __init__(__self__, *,
                 api_server_profile: Optional[pulumi.Input['ClusterApiServerProfileArgs']] = None,
                 cluster_profile: Optional[pulumi.Input['ClusterClusterProfileArgs']] = None,
                 console_url: Optional[pulumi.Input[str]] = None,
                 ingress_profile: Optional[pulumi.Input['ClusterIngressProfileArgs']] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 main_profile: Optional[pulumi.Input['ClusterMainProfileArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_profile: Optional[pulumi.Input['ClusterNetworkProfileArgs']] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 service_principal: Optional[pulumi.Input['ClusterServicePrincipalArgs']] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 worker_profile: Optional[pulumi.Input['ClusterWorkerProfileArgs']] = None):
        """
        Input properties used for looking up and filtering Cluster resources.
        :param pulumi.Input['ClusterApiServerProfileArgs'] api_server_profile: An `api_server_profile` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input['ClusterClusterProfileArgs'] cluster_profile: A `cluster_profile` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[str] console_url: The Red Hat OpenShift cluster console URL.
        :param pulumi.Input['ClusterIngressProfileArgs'] ingress_profile: An `ingress_profile` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[str] location: The location where the Azure Red Hat OpenShift Cluster should be created. Changing this forces a new resource to be created.
        :param pulumi.Input['ClusterMainProfileArgs'] main_profile: A `main_profile` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the Azure Red Hat OpenShift Cluster to create. Changing this forces a new resource to be created.
        :param pulumi.Input['ClusterNetworkProfileArgs'] network_profile: A `network_profile` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: Specifies the Resource Group where the Azure Red Hat OpenShift Cluster should exist. Changing this forces a new resource to be created.
        :param pulumi.Input['ClusterServicePrincipalArgs'] service_principal: A `service_principal` block as defined below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input['ClusterWorkerProfileArgs'] worker_profile: A `worker_profile` block as defined below. Changing this forces a new resource to be created.
        """
        if api_server_profile is not None:
            pulumi.set(__self__, "api_server_profile", api_server_profile)
        if cluster_profile is not None:
            pulumi.set(__self__, "cluster_profile", cluster_profile)
        if console_url is not None:
            pulumi.set(__self__, "console_url", console_url)
        if ingress_profile is not None:
            pulumi.set(__self__, "ingress_profile", ingress_profile)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if main_profile is not None:
            pulumi.set(__self__, "main_profile", main_profile)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if network_profile is not None:
            pulumi.set(__self__, "network_profile", network_profile)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if service_principal is not None:
            pulumi.set(__self__, "service_principal", service_principal)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if worker_profile is not None:
            pulumi.set(__self__, "worker_profile", worker_profile)

    @property
    @pulumi.getter(name="apiServerProfile")
    def api_server_profile(self) -> Optional[pulumi.Input['ClusterApiServerProfileArgs']]:
        """
        An `api_server_profile` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "api_server_profile")

    @api_server_profile.setter
    def api_server_profile(self, value: Optional[pulumi.Input['ClusterApiServerProfileArgs']]):
        pulumi.set(self, "api_server_profile", value)

    @property
    @pulumi.getter(name="clusterProfile")
    def cluster_profile(self) -> Optional[pulumi.Input['ClusterClusterProfileArgs']]:
        """
        A `cluster_profile` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "cluster_profile")

    @cluster_profile.setter
    def cluster_profile(self, value: Optional[pulumi.Input['ClusterClusterProfileArgs']]):
        pulumi.set(self, "cluster_profile", value)

    @property
    @pulumi.getter(name="consoleUrl")
    def console_url(self) -> Optional[pulumi.Input[str]]:
        """
        The Red Hat OpenShift cluster console URL.
        """
        return pulumi.get(self, "console_url")

    @console_url.setter
    def console_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "console_url", value)

    @property
    @pulumi.getter(name="ingressProfile")
    def ingress_profile(self) -> Optional[pulumi.Input['ClusterIngressProfileArgs']]:
        """
        An `ingress_profile` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "ingress_profile")

    @ingress_profile.setter
    def ingress_profile(self, value: Optional[pulumi.Input['ClusterIngressProfileArgs']]):
        pulumi.set(self, "ingress_profile", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        The location where the Azure Red Hat OpenShift Cluster should be created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter(name="mainProfile")
    def main_profile(self) -> Optional[pulumi.Input['ClusterMainProfileArgs']]:
        """
        A `main_profile` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "main_profile")

    @main_profile.setter
    def main_profile(self, value: Optional[pulumi.Input['ClusterMainProfileArgs']]):
        pulumi.set(self, "main_profile", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Azure Red Hat OpenShift Cluster to create. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="networkProfile")
    def network_profile(self) -> Optional[pulumi.Input['ClusterNetworkProfileArgs']]:
        """
        A `network_profile` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "network_profile")

    @network_profile.setter
    def network_profile(self, value: Optional[pulumi.Input['ClusterNetworkProfileArgs']]):
        pulumi.set(self, "network_profile", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the Resource Group where the Azure Red Hat OpenShift Cluster should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter(name="servicePrincipal")
    def service_principal(self) -> Optional[pulumi.Input['ClusterServicePrincipalArgs']]:
        """
        A `service_principal` block as defined below.
        """
        return pulumi.get(self, "service_principal")

    @service_principal.setter
    def service_principal(self, value: Optional[pulumi.Input['ClusterServicePrincipalArgs']]):
        pulumi.set(self, "service_principal", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="workerProfile")
    def worker_profile(self) -> Optional[pulumi.Input['ClusterWorkerProfileArgs']]:
        """
        A `worker_profile` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "worker_profile")

    @worker_profile.setter
    def worker_profile(self, value: Optional[pulumi.Input['ClusterWorkerProfileArgs']]):
        pulumi.set(self, "worker_profile", value)


class Cluster(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_server_profile: Optional[pulumi.Input[Union['ClusterApiServerProfileArgs', 'ClusterApiServerProfileArgsDict']]] = None,
                 cluster_profile: Optional[pulumi.Input[Union['ClusterClusterProfileArgs', 'ClusterClusterProfileArgsDict']]] = None,
                 ingress_profile: Optional[pulumi.Input[Union['ClusterIngressProfileArgs', 'ClusterIngressProfileArgsDict']]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 main_profile: Optional[pulumi.Input[Union['ClusterMainProfileArgs', 'ClusterMainProfileArgsDict']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_profile: Optional[pulumi.Input[Union['ClusterNetworkProfileArgs', 'ClusterNetworkProfileArgsDict']]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 service_principal: Optional[pulumi.Input[Union['ClusterServicePrincipalArgs', 'ClusterServicePrincipalArgsDict']]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 worker_profile: Optional[pulumi.Input[Union['ClusterWorkerProfileArgs', 'ClusterWorkerProfileArgsDict']]] = None,
                 __props__=None):
        """
        Manages a fully managed Azure Red Hat OpenShift Cluster (also known as ARO).

        > **Note:** All arguments including the client secret will be stored in the raw state as plain-text. [Read more about sensitive data in state](https://www.terraform.io/docs/state/sensitive-data.html).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure
        import pulumi_azuread as azuread

        example = azure.core.get_client_config()
        example_get_client_config = azuread.get_client_config()
        example_application = azuread.Application("example", display_name="example-aro")
        example_service_principal = azuread.ServicePrincipal("example", client_id=example_application.client_id)
        example_service_principal_password = azuread.ServicePrincipalPassword("example", service_principal_id=example_service_principal.object_id)
        redhatopenshift = azuread.get_service_principal(client_id="f1dd0a37-89c6-4e07-bcd1-ffd3d43d8875")
        example_resource_group = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West US")
        example_virtual_network = azure.network.VirtualNetwork("example",
            name="example-vnet",
            address_spaces=["10.0.0.0/22"],
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name)
        role_network1 = azure.authorization.Assignment("role_network1",
            scope=example_virtual_network.id,
            role_definition_name="Network Contributor",
            principal_id=example_service_principal.object_id)
        role_network2 = azure.authorization.Assignment("role_network2",
            scope=example_virtual_network.id,
            role_definition_name="Network Contributor",
            principal_id=redhatopenshift.object_id)
        main_subnet = azure.network.Subnet("main_subnet",
            name="main-subnet",
            resource_group_name=example_resource_group.name,
            virtual_network_name=example_virtual_network.name,
            address_prefixes=["10.0.0.0/23"],
            service_endpoints=[
                "Microsoft.Storage",
                "Microsoft.ContainerRegistry",
            ])
        worker_subnet = azure.network.Subnet("worker_subnet",
            name="worker-subnet",
            resource_group_name=example_resource_group.name,
            virtual_network_name=example_virtual_network.name,
            address_prefixes=["10.0.2.0/23"],
            service_endpoints=[
                "Microsoft.Storage",
                "Microsoft.ContainerRegistry",
            ])
        example_cluster = azure.redhatopenshift.Cluster("example",
            name="examplearo",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name,
            cluster_profile={
                "domain": "aro-example.com",
                "version": "4.13.23",
            },
            network_profile={
                "pod_cidr": "10.128.0.0/14",
                "service_cidr": "172.30.0.0/16",
            },
            main_profile={
                "vm_size": "Standard_D8s_v3",
                "subnet_id": main_subnet.id,
            },
            api_server_profile={
                "visibility": "Public",
            },
            ingress_profile={
                "visibility": "Public",
            },
            worker_profile={
                "vm_size": "Standard_D4s_v3",
                "disk_size_gb": 128,
                "node_count": 3,
                "subnet_id": worker_subnet.id,
            },
            service_principal={
                "client_id": example_application.client_id,
                "client_secret": example_service_principal_password.value,
            },
            opts = pulumi.ResourceOptions(depends_on=[
                    role_network1,
                    role_network2,
                ]))
        pulumi.export("consoleUrl", example_cluster.console_url)
        ```

        ## Import

        Red Hat OpenShift Clusters can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:redhatopenshift/cluster:Cluster cluster1 /subscriptions/00000000-0000-0000-0000-000000000000/resourcegroups/group1/providers/Microsoft.RedHatOpenShift/openShiftClusters/cluster1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ClusterApiServerProfileArgs', 'ClusterApiServerProfileArgsDict']] api_server_profile: An `api_server_profile` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['ClusterClusterProfileArgs', 'ClusterClusterProfileArgsDict']] cluster_profile: A `cluster_profile` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['ClusterIngressProfileArgs', 'ClusterIngressProfileArgsDict']] ingress_profile: An `ingress_profile` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[str] location: The location where the Azure Red Hat OpenShift Cluster should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['ClusterMainProfileArgs', 'ClusterMainProfileArgsDict']] main_profile: A `main_profile` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the Azure Red Hat OpenShift Cluster to create. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['ClusterNetworkProfileArgs', 'ClusterNetworkProfileArgsDict']] network_profile: A `network_profile` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: Specifies the Resource Group where the Azure Red Hat OpenShift Cluster should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['ClusterServicePrincipalArgs', 'ClusterServicePrincipalArgsDict']] service_principal: A `service_principal` block as defined below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[Union['ClusterWorkerProfileArgs', 'ClusterWorkerProfileArgsDict']] worker_profile: A `worker_profile` block as defined below. Changing this forces a new resource to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ClusterArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a fully managed Azure Red Hat OpenShift Cluster (also known as ARO).

        > **Note:** All arguments including the client secret will be stored in the raw state as plain-text. [Read more about sensitive data in state](https://www.terraform.io/docs/state/sensitive-data.html).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure
        import pulumi_azuread as azuread

        example = azure.core.get_client_config()
        example_get_client_config = azuread.get_client_config()
        example_application = azuread.Application("example", display_name="example-aro")
        example_service_principal = azuread.ServicePrincipal("example", client_id=example_application.client_id)
        example_service_principal_password = azuread.ServicePrincipalPassword("example", service_principal_id=example_service_principal.object_id)
        redhatopenshift = azuread.get_service_principal(client_id="f1dd0a37-89c6-4e07-bcd1-ffd3d43d8875")
        example_resource_group = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West US")
        example_virtual_network = azure.network.VirtualNetwork("example",
            name="example-vnet",
            address_spaces=["10.0.0.0/22"],
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name)
        role_network1 = azure.authorization.Assignment("role_network1",
            scope=example_virtual_network.id,
            role_definition_name="Network Contributor",
            principal_id=example_service_principal.object_id)
        role_network2 = azure.authorization.Assignment("role_network2",
            scope=example_virtual_network.id,
            role_definition_name="Network Contributor",
            principal_id=redhatopenshift.object_id)
        main_subnet = azure.network.Subnet("main_subnet",
            name="main-subnet",
            resource_group_name=example_resource_group.name,
            virtual_network_name=example_virtual_network.name,
            address_prefixes=["10.0.0.0/23"],
            service_endpoints=[
                "Microsoft.Storage",
                "Microsoft.ContainerRegistry",
            ])
        worker_subnet = azure.network.Subnet("worker_subnet",
            name="worker-subnet",
            resource_group_name=example_resource_group.name,
            virtual_network_name=example_virtual_network.name,
            address_prefixes=["10.0.2.0/23"],
            service_endpoints=[
                "Microsoft.Storage",
                "Microsoft.ContainerRegistry",
            ])
        example_cluster = azure.redhatopenshift.Cluster("example",
            name="examplearo",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name,
            cluster_profile={
                "domain": "aro-example.com",
                "version": "4.13.23",
            },
            network_profile={
                "pod_cidr": "10.128.0.0/14",
                "service_cidr": "172.30.0.0/16",
            },
            main_profile={
                "vm_size": "Standard_D8s_v3",
                "subnet_id": main_subnet.id,
            },
            api_server_profile={
                "visibility": "Public",
            },
            ingress_profile={
                "visibility": "Public",
            },
            worker_profile={
                "vm_size": "Standard_D4s_v3",
                "disk_size_gb": 128,
                "node_count": 3,
                "subnet_id": worker_subnet.id,
            },
            service_principal={
                "client_id": example_application.client_id,
                "client_secret": example_service_principal_password.value,
            },
            opts = pulumi.ResourceOptions(depends_on=[
                    role_network1,
                    role_network2,
                ]))
        pulumi.export("consoleUrl", example_cluster.console_url)
        ```

        ## Import

        Red Hat OpenShift Clusters can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:redhatopenshift/cluster:Cluster cluster1 /subscriptions/00000000-0000-0000-0000-000000000000/resourcegroups/group1/providers/Microsoft.RedHatOpenShift/openShiftClusters/cluster1
        ```

        :param str resource_name: The name of the resource.
        :param ClusterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ClusterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 api_server_profile: Optional[pulumi.Input[Union['ClusterApiServerProfileArgs', 'ClusterApiServerProfileArgsDict']]] = None,
                 cluster_profile: Optional[pulumi.Input[Union['ClusterClusterProfileArgs', 'ClusterClusterProfileArgsDict']]] = None,
                 ingress_profile: Optional[pulumi.Input[Union['ClusterIngressProfileArgs', 'ClusterIngressProfileArgsDict']]] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 main_profile: Optional[pulumi.Input[Union['ClusterMainProfileArgs', 'ClusterMainProfileArgsDict']]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 network_profile: Optional[pulumi.Input[Union['ClusterNetworkProfileArgs', 'ClusterNetworkProfileArgsDict']]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 service_principal: Optional[pulumi.Input[Union['ClusterServicePrincipalArgs', 'ClusterServicePrincipalArgsDict']]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 worker_profile: Optional[pulumi.Input[Union['ClusterWorkerProfileArgs', 'ClusterWorkerProfileArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ClusterArgs.__new__(ClusterArgs)

            if api_server_profile is None and not opts.urn:
                raise TypeError("Missing required property 'api_server_profile'")
            __props__.__dict__["api_server_profile"] = api_server_profile
            if cluster_profile is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_profile'")
            __props__.__dict__["cluster_profile"] = cluster_profile
            if ingress_profile is None and not opts.urn:
                raise TypeError("Missing required property 'ingress_profile'")
            __props__.__dict__["ingress_profile"] = ingress_profile
            __props__.__dict__["location"] = location
            if main_profile is None and not opts.urn:
                raise TypeError("Missing required property 'main_profile'")
            __props__.__dict__["main_profile"] = main_profile
            __props__.__dict__["name"] = name
            if network_profile is None and not opts.urn:
                raise TypeError("Missing required property 'network_profile'")
            __props__.__dict__["network_profile"] = network_profile
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            if service_principal is None and not opts.urn:
                raise TypeError("Missing required property 'service_principal'")
            __props__.__dict__["service_principal"] = service_principal
            __props__.__dict__["tags"] = tags
            if worker_profile is None and not opts.urn:
                raise TypeError("Missing required property 'worker_profile'")
            __props__.__dict__["worker_profile"] = worker_profile
            __props__.__dict__["console_url"] = None
        super(Cluster, __self__).__init__(
            'azure:redhatopenshift/cluster:Cluster',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            api_server_profile: Optional[pulumi.Input[Union['ClusterApiServerProfileArgs', 'ClusterApiServerProfileArgsDict']]] = None,
            cluster_profile: Optional[pulumi.Input[Union['ClusterClusterProfileArgs', 'ClusterClusterProfileArgsDict']]] = None,
            console_url: Optional[pulumi.Input[str]] = None,
            ingress_profile: Optional[pulumi.Input[Union['ClusterIngressProfileArgs', 'ClusterIngressProfileArgsDict']]] = None,
            location: Optional[pulumi.Input[str]] = None,
            main_profile: Optional[pulumi.Input[Union['ClusterMainProfileArgs', 'ClusterMainProfileArgsDict']]] = None,
            name: Optional[pulumi.Input[str]] = None,
            network_profile: Optional[pulumi.Input[Union['ClusterNetworkProfileArgs', 'ClusterNetworkProfileArgsDict']]] = None,
            resource_group_name: Optional[pulumi.Input[str]] = None,
            service_principal: Optional[pulumi.Input[Union['ClusterServicePrincipalArgs', 'ClusterServicePrincipalArgsDict']]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            worker_profile: Optional[pulumi.Input[Union['ClusterWorkerProfileArgs', 'ClusterWorkerProfileArgsDict']]] = None) -> 'Cluster':
        """
        Get an existing Cluster resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['ClusterApiServerProfileArgs', 'ClusterApiServerProfileArgsDict']] api_server_profile: An `api_server_profile` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['ClusterClusterProfileArgs', 'ClusterClusterProfileArgsDict']] cluster_profile: A `cluster_profile` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[str] console_url: The Red Hat OpenShift cluster console URL.
        :param pulumi.Input[Union['ClusterIngressProfileArgs', 'ClusterIngressProfileArgsDict']] ingress_profile: An `ingress_profile` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[str] location: The location where the Azure Red Hat OpenShift Cluster should be created. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['ClusterMainProfileArgs', 'ClusterMainProfileArgsDict']] main_profile: A `main_profile` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[str] name: The name of the Azure Red Hat OpenShift Cluster to create. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['ClusterNetworkProfileArgs', 'ClusterNetworkProfileArgsDict']] network_profile: A `network_profile` block as defined below. Changing this forces a new resource to be created.
        :param pulumi.Input[str] resource_group_name: Specifies the Resource Group where the Azure Red Hat OpenShift Cluster should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['ClusterServicePrincipalArgs', 'ClusterServicePrincipalArgsDict']] service_principal: A `service_principal` block as defined below.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] tags: A mapping of tags to assign to the resource.
        :param pulumi.Input[Union['ClusterWorkerProfileArgs', 'ClusterWorkerProfileArgsDict']] worker_profile: A `worker_profile` block as defined below. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ClusterState.__new__(_ClusterState)

        __props__.__dict__["api_server_profile"] = api_server_profile
        __props__.__dict__["cluster_profile"] = cluster_profile
        __props__.__dict__["console_url"] = console_url
        __props__.__dict__["ingress_profile"] = ingress_profile
        __props__.__dict__["location"] = location
        __props__.__dict__["main_profile"] = main_profile
        __props__.__dict__["name"] = name
        __props__.__dict__["network_profile"] = network_profile
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["service_principal"] = service_principal
        __props__.__dict__["tags"] = tags
        __props__.__dict__["worker_profile"] = worker_profile
        return Cluster(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="apiServerProfile")
    def api_server_profile(self) -> pulumi.Output['outputs.ClusterApiServerProfile']:
        """
        An `api_server_profile` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "api_server_profile")

    @property
    @pulumi.getter(name="clusterProfile")
    def cluster_profile(self) -> pulumi.Output['outputs.ClusterClusterProfile']:
        """
        A `cluster_profile` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "cluster_profile")

    @property
    @pulumi.getter(name="consoleUrl")
    def console_url(self) -> pulumi.Output[str]:
        """
        The Red Hat OpenShift cluster console URL.
        """
        return pulumi.get(self, "console_url")

    @property
    @pulumi.getter(name="ingressProfile")
    def ingress_profile(self) -> pulumi.Output['outputs.ClusterIngressProfile']:
        """
        An `ingress_profile` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "ingress_profile")

    @property
    @pulumi.getter
    def location(self) -> pulumi.Output[str]:
        """
        The location where the Azure Red Hat OpenShift Cluster should be created. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter(name="mainProfile")
    def main_profile(self) -> pulumi.Output['outputs.ClusterMainProfile']:
        """
        A `main_profile` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "main_profile")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the Azure Red Hat OpenShift Cluster to create. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="networkProfile")
    def network_profile(self) -> pulumi.Output['outputs.ClusterNetworkProfile']:
        """
        A `network_profile` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "network_profile")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[str]:
        """
        Specifies the Resource Group where the Azure Red Hat OpenShift Cluster should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter(name="servicePrincipal")
    def service_principal(self) -> pulumi.Output['outputs.ClusterServicePrincipal']:
        """
        A `service_principal` block as defined below.
        """
        return pulumi.get(self, "service_principal")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="workerProfile")
    def worker_profile(self) -> pulumi.Output['outputs.ClusterWorkerProfile']:
        """
        A `worker_profile` block as defined below. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "worker_profile")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AssignmentVirtualMachineScaleSetArgs', 'AssignmentVirtualMachineScaleSet']

@pulumi.input_type
class AssignmentVirtualMachineScaleSetArgs:
    def __init__(__self__, *,
                 maintenance_configuration_id: pulumi.Input[str],
                 virtual_machine_scale_set_id: pulumi.Input[str],
                 location: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a AssignmentVirtualMachineScaleSet resource.
        :param pulumi.Input[str] maintenance_configuration_id: Specifies the ID of the Maintenance Configuration Resource. Changing this forces a new resource to be created.
        :param pulumi.Input[str] virtual_machine_scale_set_id: Specifies the Virtual Machine Scale Set ID to which the Maintenance Configuration will be assigned. Changing this forces a new resource to be created.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "maintenance_configuration_id", maintenance_configuration_id)
        pulumi.set(__self__, "virtual_machine_scale_set_id", virtual_machine_scale_set_id)
        if location is not None:
            pulumi.set(__self__, "location", location)

    @property
    @pulumi.getter(name="maintenanceConfigurationId")
    def maintenance_configuration_id(self) -> pulumi.Input[str]:
        """
        Specifies the ID of the Maintenance Configuration Resource. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "maintenance_configuration_id")

    @maintenance_configuration_id.setter
    def maintenance_configuration_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "maintenance_configuration_id", value)

    @property
    @pulumi.getter(name="virtualMachineScaleSetId")
    def virtual_machine_scale_set_id(self) -> pulumi.Input[str]:
        """
        Specifies the Virtual Machine Scale Set ID to which the Maintenance Configuration will be assigned. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "virtual_machine_scale_set_id")

    @virtual_machine_scale_set_id.setter
    def virtual_machine_scale_set_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "virtual_machine_scale_set_id", value)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)


@pulumi.input_type
class _AssignmentVirtualMachineScaleSetState:
    def __init__(__self__, *,
                 location: Optional[pulumi.Input[str]] = None,
                 maintenance_configuration_id: Optional[pulumi.Input[str]] = None,
                 virtual_machine_scale_set_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AssignmentVirtualMachineScaleSet resources.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] maintenance_configuration_id: Specifies the ID of the Maintenance Configuration Resource. Changing this forces a new resource to be created.
        :param pulumi.Input[str] virtual_machine_scale_set_id: Specifies the Virtual Machine Scale Set ID to which the Maintenance Configuration will be assigned. Changing this forces a new resource to be created.
        """
        if location is not None:
            pulumi.set(__self__, "location", location)
        if maintenance_configuration_id is not None:
            pulumi.set(__self__, "maintenance_configuration_id", maintenance_configuration_id)
        if virtual_machine_scale_set_id is not None:
            pulumi.set(__self__, "virtual_machine_scale_set_id", virtual_machine_scale_set_id)

    @property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "location", value)

    @property
    @pulumi.getter(name="maintenanceConfigurationId")
    def maintenance_configuration_id(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the ID of the Maintenance Configuration Resource. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "maintenance_configuration_id")

    @maintenance_configuration_id.setter
    def maintenance_configuration_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "maintenance_configuration_id", value)

    @property
    @pulumi.getter(name="virtualMachineScaleSetId")
    def virtual_machine_scale_set_id(self) -> Optional[pulumi.Input[str]]:
        """
        Specifies the Virtual Machine Scale Set ID to which the Maintenance Configuration will be assigned. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "virtual_machine_scale_set_id")

    @virtual_machine_scale_set_id.setter
    def virtual_machine_scale_set_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "virtual_machine_scale_set_id", value)


class AssignmentVirtualMachineScaleSet(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 maintenance_configuration_id: Optional[pulumi.Input[str]] = None,
                 virtual_machine_scale_set_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a maintenance assignment to a virtual machine scale set.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_virtual_network = azure.network.VirtualNetwork("example",
            name="example-network",
            address_spaces=["10.0.0.0/16"],
            location=example.location,
            resource_group_name=example.name)
        example_subnet = azure.network.Subnet("example",
            name="internal",
            resource_group_name=example.name,
            virtual_network_name=example_virtual_network.name,
            address_prefixes=["10.0.2.0/24"])
        example_public_ip = azure.network.PublicIp("example",
            name=example.name,
            location=example.location,
            resource_group_name=example.name,
            allocation_method="Static")
        example_load_balancer = azure.lb.LoadBalancer("example",
            name=example.name,
            location=example.location,
            resource_group_name=example.name,
            frontend_ip_configurations=[{
                "name": "internal",
                "public_ip_address_id": example_public_ip.id,
            }])
        example_backend_address_pool = azure.lb.BackendAddressPool("example",
            name="example",
            loadbalancer_id=example_load_balancer.id)
        example_probe = azure.lb.Probe("example",
            name="example",
            loadbalancer_id=example_load_balancer.id,
            port=22,
            protocol="Tcp")
        example_rule = azure.lb.Rule("example",
            name="example",
            loadbalancer_id=example_load_balancer.id,
            probe_id=example_probe.id,
            frontend_ip_configuration_name="internal",
            protocol="Tcp",
            frontend_port=22,
            backend_port=22)
        example_configuration = azure.maintenance.Configuration("example",
            name="example",
            resource_group_name=example.name,
            location=example.location,
            scope="OSImage",
            visibility="Custom",
            window={
                "start_date_time": "2021-12-31 00:00",
                "expiration_date_time": "9999-12-31 00:00",
                "duration": "06:00",
                "time_zone": "Pacific Standard Time",
                "recur_every": "1Days",
            })
        example_network_interface = azure.network.NetworkInterface("example",
            name="sample-nic",
            location=example.location,
            resource_group_name=example.name,
            ip_configurations=[{
                "name": "testconfiguration1",
                "private_ip_address_allocation": "Dynamic",
            }])
        example_linux_virtual_machine = azure.compute.LinuxVirtualMachine("example",
            name="example-machine",
            resource_group_name=example.name,
            location=example.location,
            size="Standard_F2",
            admin_username="adminuser",
            network_interface_ids=[example_network_interface.id],
            os_disk={
                "caching": "ReadWrite",
                "storage_account_type": "Standard_LRS",
            })
        example_linux_virtual_machine_scale_set = azure.compute.LinuxVirtualMachineScaleSet("example",
            name="example",
            resource_group_name=example.name,
            location=example.location,
            sku="Standard_F2",
            instances=1,
            admin_username="adminuser",
            admin_password="P@ssword1234!",
            upgrade_mode="Automatic",
            health_probe_id=example_probe.id,
            disable_password_authentication=False,
            source_image_reference={
                "publisher": "Canonical",
                "offer": "0001-com-ubuntu-server-jammy",
                "sku": "22_04-lts",
                "version": "latest",
            },
            os_disk={
                "storage_account_type": "Standard_LRS",
                "caching": "ReadWrite",
            },
            network_interfaces=[{
                "name": "example",
                "primary": True,
                "ip_configurations": [{
                    "name": "internal",
                    "primary": True,
                    "subnet_id": example_subnet.id,
                    "load_balancer_backend_address_pool_ids": [example_backend_address_pool.id],
                }],
            }],
            automatic_os_upgrade_policy={
                "disable_automatic_rollback": True,
                "enable_automatic_os_upgrade": True,
            },
            rolling_upgrade_policy={
                "max_batch_instance_percent": 20,
                "max_unhealthy_instance_percent": 20,
                "max_unhealthy_upgraded_instance_percent": 20,
                "pause_time_between_batches": "PT0S",
            },
            opts = pulumi.ResourceOptions(depends_on=[example_rule]))
        example_assignment_virtual_machine_scale_set = azure.maintenance.AssignmentVirtualMachineScaleSet("example",
            location=example.location,
            maintenance_configuration_id=example_configuration.id,
            virtual_machine_scale_set_id=example_linux_virtual_machine.id)
        ```

        ## Import

        Maintenance Assignment can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:maintenance/assignmentVirtualMachineScaleSet:AssignmentVirtualMachineScaleSet example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resGroup1/providers/Microsoft.Compute/virtualMachineScaleSets/vmss1/providers/Microsoft.Maintenance/configurationAssignments/assign1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] maintenance_configuration_id: Specifies the ID of the Maintenance Configuration Resource. Changing this forces a new resource to be created.
        :param pulumi.Input[str] virtual_machine_scale_set_id: Specifies the Virtual Machine Scale Set ID to which the Maintenance Configuration will be assigned. Changing this forces a new resource to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AssignmentVirtualMachineScaleSetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a maintenance assignment to a virtual machine scale set.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_virtual_network = azure.network.VirtualNetwork("example",
            name="example-network",
            address_spaces=["10.0.0.0/16"],
            location=example.location,
            resource_group_name=example.name)
        example_subnet = azure.network.Subnet("example",
            name="internal",
            resource_group_name=example.name,
            virtual_network_name=example_virtual_network.name,
            address_prefixes=["10.0.2.0/24"])
        example_public_ip = azure.network.PublicIp("example",
            name=example.name,
            location=example.location,
            resource_group_name=example.name,
            allocation_method="Static")
        example_load_balancer = azure.lb.LoadBalancer("example",
            name=example.name,
            location=example.location,
            resource_group_name=example.name,
            frontend_ip_configurations=[{
                "name": "internal",
                "public_ip_address_id": example_public_ip.id,
            }])
        example_backend_address_pool = azure.lb.BackendAddressPool("example",
            name="example",
            loadbalancer_id=example_load_balancer.id)
        example_probe = azure.lb.Probe("example",
            name="example",
            loadbalancer_id=example_load_balancer.id,
            port=22,
            protocol="Tcp")
        example_rule = azure.lb.Rule("example",
            name="example",
            loadbalancer_id=example_load_balancer.id,
            probe_id=example_probe.id,
            frontend_ip_configuration_name="internal",
            protocol="Tcp",
            frontend_port=22,
            backend_port=22)
        example_configuration = azure.maintenance.Configuration("example",
            name="example",
            resource_group_name=example.name,
            location=example.location,
            scope="OSImage",
            visibility="Custom",
            window={
                "start_date_time": "2021-12-31 00:00",
                "expiration_date_time": "9999-12-31 00:00",
                "duration": "06:00",
                "time_zone": "Pacific Standard Time",
                "recur_every": "1Days",
            })
        example_network_interface = azure.network.NetworkInterface("example",
            name="sample-nic",
            location=example.location,
            resource_group_name=example.name,
            ip_configurations=[{
                "name": "testconfiguration1",
                "private_ip_address_allocation": "Dynamic",
            }])
        example_linux_virtual_machine = azure.compute.LinuxVirtualMachine("example",
            name="example-machine",
            resource_group_name=example.name,
            location=example.location,
            size="Standard_F2",
            admin_username="adminuser",
            network_interface_ids=[example_network_interface.id],
            os_disk={
                "caching": "ReadWrite",
                "storage_account_type": "Standard_LRS",
            })
        example_linux_virtual_machine_scale_set = azure.compute.LinuxVirtualMachineScaleSet("example",
            name="example",
            resource_group_name=example.name,
            location=example.location,
            sku="Standard_F2",
            instances=1,
            admin_username="adminuser",
            admin_password="P@ssword1234!",
            upgrade_mode="Automatic",
            health_probe_id=example_probe.id,
            disable_password_authentication=False,
            source_image_reference={
                "publisher": "Canonical",
                "offer": "0001-com-ubuntu-server-jammy",
                "sku": "22_04-lts",
                "version": "latest",
            },
            os_disk={
                "storage_account_type": "Standard_LRS",
                "caching": "ReadWrite",
            },
            network_interfaces=[{
                "name": "example",
                "primary": True,
                "ip_configurations": [{
                    "name": "internal",
                    "primary": True,
                    "subnet_id": example_subnet.id,
                    "load_balancer_backend_address_pool_ids": [example_backend_address_pool.id],
                }],
            }],
            automatic_os_upgrade_policy={
                "disable_automatic_rollback": True,
                "enable_automatic_os_upgrade": True,
            },
            rolling_upgrade_policy={
                "max_batch_instance_percent": 20,
                "max_unhealthy_instance_percent": 20,
                "max_unhealthy_upgraded_instance_percent": 20,
                "pause_time_between_batches": "PT0S",
            },
            opts = pulumi.ResourceOptions(depends_on=[example_rule]))
        example_assignment_virtual_machine_scale_set = azure.maintenance.AssignmentVirtualMachineScaleSet("example",
            location=example.location,
            maintenance_configuration_id=example_configuration.id,
            virtual_machine_scale_set_id=example_linux_virtual_machine.id)
        ```

        ## Import

        Maintenance Assignment can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:maintenance/assignmentVirtualMachineScaleSet:AssignmentVirtualMachineScaleSet example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resGroup1/providers/Microsoft.Compute/virtualMachineScaleSets/vmss1/providers/Microsoft.Maintenance/configurationAssignments/assign1
        ```

        :param str resource_name: The name of the resource.
        :param AssignmentVirtualMachineScaleSetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AssignmentVirtualMachineScaleSetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 location: Optional[pulumi.Input[str]] = None,
                 maintenance_configuration_id: Optional[pulumi.Input[str]] = None,
                 virtual_machine_scale_set_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AssignmentVirtualMachineScaleSetArgs.__new__(AssignmentVirtualMachineScaleSetArgs)

            __props__.__dict__["location"] = location
            if maintenance_configuration_id is None and not opts.urn:
                raise TypeError("Missing required property 'maintenance_configuration_id'")
            __props__.__dict__["maintenance_configuration_id"] = maintenance_configuration_id
            if virtual_machine_scale_set_id is None and not opts.urn:
                raise TypeError("Missing required property 'virtual_machine_scale_set_id'")
            __props__.__dict__["virtual_machine_scale_set_id"] = virtual_machine_scale_set_id
        super(AssignmentVirtualMachineScaleSet, __self__).__init__(
            'azure:maintenance/assignmentVirtualMachineScaleSet:AssignmentVirtualMachineScaleSet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            location: Optional[pulumi.Input[str]] = None,
            maintenance_configuration_id: Optional[pulumi.Input[str]] = None,
            virtual_machine_scale_set_id: Optional[pulumi.Input[str]] = None) -> 'AssignmentVirtualMachineScaleSet':
        """
        Get an existing AssignmentVirtualMachineScaleSet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] location: Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        :param pulumi.Input[str] maintenance_configuration_id: Specifies the ID of the Maintenance Configuration Resource. Changing this forces a new resource to be created.
        :param pulumi.Input[str] virtual_machine_scale_set_id: Specifies the Virtual Machine Scale Set ID to which the Maintenance Configuration will be assigned. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AssignmentVirtualMachineScaleSetState.__new__(_AssignmentVirtualMachineScaleSetState)

        __props__.__dict__["location"] = location
        __props__.__dict__["maintenance_configuration_id"] = maintenance_configuration_id
        __props__.__dict__["virtual_machine_scale_set_id"] = virtual_machine_scale_set_id
        return AssignmentVirtualMachineScaleSet(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def location(self) -> pulumi.Output[str]:
        """
        Specifies the supported Azure location where the resource exists. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @property
    @pulumi.getter(name="maintenanceConfigurationId")
    def maintenance_configuration_id(self) -> pulumi.Output[str]:
        """
        Specifies the ID of the Maintenance Configuration Resource. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "maintenance_configuration_id")

    @property
    @pulumi.getter(name="virtualMachineScaleSetId")
    def virtual_machine_scale_set_id(self) -> pulumi.Output[str]:
        """
        Specifies the Virtual Machine Scale Set ID to which the Maintenance Configuration will be assigned. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "virtual_machine_scale_set_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['VmwareReplicationPolicyAssociationArgs', 'VmwareReplicationPolicyAssociation']

@pulumi.input_type
class VmwareReplicationPolicyAssociationArgs:
    def __init__(__self__, *,
                 policy_id: pulumi.Input[str],
                 recovery_vault_id: pulumi.Input[str],
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a VmwareReplicationPolicyAssociation resource.
        :param pulumi.Input[str] policy_id: The ID of the VMWare replication policy which to be associated. Changing this forces a new association to be created.
        :param pulumi.Input[str] recovery_vault_id: The ID of the Recovery Service Vault to which the policy should be associated.
               Changing this forces a new association to be created.
        :param pulumi.Input[str] name: The name of the replication policy association. Changing this forces a new association to be created.
        """
        pulumi.set(__self__, "policy_id", policy_id)
        pulumi.set(__self__, "recovery_vault_id", recovery_vault_id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> pulumi.Input[str]:
        """
        The ID of the VMWare replication policy which to be associated. Changing this forces a new association to be created.
        """
        return pulumi.get(self, "policy_id")

    @policy_id.setter
    def policy_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "policy_id", value)

    @property
    @pulumi.getter(name="recoveryVaultId")
    def recovery_vault_id(self) -> pulumi.Input[str]:
        """
        The ID of the Recovery Service Vault to which the policy should be associated.
        Changing this forces a new association to be created.
        """
        return pulumi.get(self, "recovery_vault_id")

    @recovery_vault_id.setter
    def recovery_vault_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "recovery_vault_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the replication policy association. Changing this forces a new association to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _VmwareReplicationPolicyAssociationState:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[str]] = None,
                 policy_id: Optional[pulumi.Input[str]] = None,
                 recovery_vault_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering VmwareReplicationPolicyAssociation resources.
        :param pulumi.Input[str] name: The name of the replication policy association. Changing this forces a new association to be created.
        :param pulumi.Input[str] policy_id: The ID of the VMWare replication policy which to be associated. Changing this forces a new association to be created.
        :param pulumi.Input[str] recovery_vault_id: The ID of the Recovery Service Vault to which the policy should be associated.
               Changing this forces a new association to be created.
        """
        if name is not None:
            pulumi.set(__self__, "name", name)
        if policy_id is not None:
            pulumi.set(__self__, "policy_id", policy_id)
        if recovery_vault_id is not None:
            pulumi.set(__self__, "recovery_vault_id", recovery_vault_id)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the replication policy association. Changing this forces a new association to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the VMWare replication policy which to be associated. Changing this forces a new association to be created.
        """
        return pulumi.get(self, "policy_id")

    @policy_id.setter
    def policy_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "policy_id", value)

    @property
    @pulumi.getter(name="recoveryVaultId")
    def recovery_vault_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the Recovery Service Vault to which the policy should be associated.
        Changing this forces a new association to be created.
        """
        return pulumi.get(self, "recovery_vault_id")

    @recovery_vault_id.setter
    def recovery_vault_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "recovery_vault_id", value)


class VmwareReplicationPolicyAssociation(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 policy_id: Optional[pulumi.Input[str]] = None,
                 recovery_vault_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages an Azure Site Recovery replication policy for VMWare within a Recovery Vault.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-rg",
            location="East US")
        example_vault = azure.recoveryservices.Vault("example",
            name="example-recovery-vault",
            location=example.location,
            resource_group_name=example.name,
            sku="Standard")
        example_vm_ware_replication_policy = azure.siterecovery.VMWareReplicationPolicy("example",
            name="example-policy",
            recovery_vault_id=example_vault.id,
            recovery_point_retention_in_minutes=1440,
            application_consistent_snapshot_frequency_in_minutes=240)
        example_vmware_replication_policy_association = azure.siterecovery.VmwareReplicationPolicyAssociation("example",
            name="example-association",
            recovery_vault_id=example_vault.id,
            policy_id=example_vm_ware_replication_policy.id)
        ```

        ## Import

        Site Recovery Replication Policies can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:siterecovery/vmwareReplicationPolicyAssociation:VmwareReplicationPolicyAssociation mypolicy /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resource-group-name/providers/Microsoft.RecoveryServices/vaults/recovery-vault-name/replicationFabrics/site-name/replicationProtectionContainers/container-name/replicationProtectionContainerMappings/mapping-name
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The name of the replication policy association. Changing this forces a new association to be created.
        :param pulumi.Input[str] policy_id: The ID of the VMWare replication policy which to be associated. Changing this forces a new association to be created.
        :param pulumi.Input[str] recovery_vault_id: The ID of the Recovery Service Vault to which the policy should be associated.
               Changing this forces a new association to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VmwareReplicationPolicyAssociationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages an Azure Site Recovery replication policy for VMWare within a Recovery Vault.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-rg",
            location="East US")
        example_vault = azure.recoveryservices.Vault("example",
            name="example-recovery-vault",
            location=example.location,
            resource_group_name=example.name,
            sku="Standard")
        example_vm_ware_replication_policy = azure.siterecovery.VMWareReplicationPolicy("example",
            name="example-policy",
            recovery_vault_id=example_vault.id,
            recovery_point_retention_in_minutes=1440,
            application_consistent_snapshot_frequency_in_minutes=240)
        example_vmware_replication_policy_association = azure.siterecovery.VmwareReplicationPolicyAssociation("example",
            name="example-association",
            recovery_vault_id=example_vault.id,
            policy_id=example_vm_ware_replication_policy.id)
        ```

        ## Import

        Site Recovery Replication Policies can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:siterecovery/vmwareReplicationPolicyAssociation:VmwareReplicationPolicyAssociation mypolicy /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/resource-group-name/providers/Microsoft.RecoveryServices/vaults/recovery-vault-name/replicationFabrics/site-name/replicationProtectionContainers/container-name/replicationProtectionContainerMappings/mapping-name
        ```

        :param str resource_name: The name of the resource.
        :param VmwareReplicationPolicyAssociationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VmwareReplicationPolicyAssociationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 policy_id: Optional[pulumi.Input[str]] = None,
                 recovery_vault_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VmwareReplicationPolicyAssociationArgs.__new__(VmwareReplicationPolicyAssociationArgs)

            __props__.__dict__["name"] = name
            if policy_id is None and not opts.urn:
                raise TypeError("Missing required property 'policy_id'")
            __props__.__dict__["policy_id"] = policy_id
            if recovery_vault_id is None and not opts.urn:
                raise TypeError("Missing required property 'recovery_vault_id'")
            __props__.__dict__["recovery_vault_id"] = recovery_vault_id
        super(VmwareReplicationPolicyAssociation, __self__).__init__(
            'azure:siterecovery/vmwareReplicationPolicyAssociation:VmwareReplicationPolicyAssociation',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            name: Optional[pulumi.Input[str]] = None,
            policy_id: Optional[pulumi.Input[str]] = None,
            recovery_vault_id: Optional[pulumi.Input[str]] = None) -> 'VmwareReplicationPolicyAssociation':
        """
        Get an existing VmwareReplicationPolicyAssociation resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] name: The name of the replication policy association. Changing this forces a new association to be created.
        :param pulumi.Input[str] policy_id: The ID of the VMWare replication policy which to be associated. Changing this forces a new association to be created.
        :param pulumi.Input[str] recovery_vault_id: The ID of the Recovery Service Vault to which the policy should be associated.
               Changing this forces a new association to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VmwareReplicationPolicyAssociationState.__new__(_VmwareReplicationPolicyAssociationState)

        __props__.__dict__["name"] = name
        __props__.__dict__["policy_id"] = policy_id
        __props__.__dict__["recovery_vault_id"] = recovery_vault_id
        return VmwareReplicationPolicyAssociation(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the replication policy association. Changing this forces a new association to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> pulumi.Output[str]:
        """
        The ID of the VMWare replication policy which to be associated. Changing this forces a new association to be created.
        """
        return pulumi.get(self, "policy_id")

    @property
    @pulumi.getter(name="recoveryVaultId")
    def recovery_vault_id(self) -> pulumi.Output[str]:
        """
        The ID of the Recovery Service Vault to which the policy should be associated.
        Changing this forces a new association to be created.
        """
        return pulumi.get(self, "recovery_vault_id")

